<? include ("barry.inc"); ?>

<? createHeader("Contacting the Developers"); ?>

<? createSubHeader("Email"); ?>

<p>The <b><i>best</i></b> way to reach the Barry developers is through the
<a href="http://sourceforge.net/mail/?group_id=153722">barry-devel mailing list</a>.
Subscribe and then post your query or comment.  This is the best
place for sending patches, reporting bugs, or asking for support.</p>

<p>If you need to contact Chris Frey, Barry's lead developer, privately,
you can send email to cdfrey @ foursquare . net.  Mention the name and
the version of the Barry package you are using when contacting Chris
directly.</p>


<? createSubHeader("Web"); ?>

<p>If you cannot use email for some reason, you can also post support
requests and bug reports on the Sourceforge
<a href="http://sourceforge.net/tracker/?group_id=153722">tracker page</a>.
</p>


<? createSubHeader("IRC"); ?>

<p>Barry developers and users occasionally hang out on the IRC channel
#barry on irc.freenode.net.</p>

